#
# spec file for package cloud-netconfig
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_name cloud-netconfig

%if "gce" == ""
%define flavor_suffix %nil
%define csp_string None
ExclusiveArch:  do-not-build
%endif
%if "gce" == "azure"
%define flavor_suffix -azure
%define csp_string Microsoft Azure
%endif
%if "gce" == "ec2"
%define flavor_suffix -ec2
%define csp_string Amazon EC2
%endif
%if "gce" == "gce"
%define flavor_suffix -gce
%define csp_string Google Compute Engine
%endif

Name:           %{base_name}%{flavor_suffix}
Version:        1.5
Release:        lp152.2.3.1
Summary:        Network configuration scripts for %{csp_string}
License:        GPL-3.0-or-later
Group:          System/Management
URL:            https://github.com/SUSE-Enceladus/cloud-netconfig
Source0:        %{base_name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%if 0%{?suse_version} == 1110
BuildRequires:  sysconfig
Requires:       sysconfig
%define _udevrulesdir %{_sysconfdir}/udev/rules.d
%else
BuildRequires:  sysconfig-netconfig
Requires:       sysconfig-netconfig
%endif
BuildRequires:  pkgconfig(udev)
Requires:       curl
Requires:       udev
%if 0%{?sles_version} == 11
# RPM in SLES 11 does not support self conflict, use otherproviders()
# workaround
Provides:       cloud-netconfig
Conflicts:      otherproviders(cloud-netconfig)
%else
Provides:       cloud-netconfig
Conflicts:      cloud-netconfig
%endif
%{?systemd_requires}

%description -n %{base_name}%{flavor_suffix}
This package contains scripts for automatically configuring network interfaces
in %{csp_string} with full support for hotplug.

%prep
%setup -q -n %{base_name}-%{version}

%build

%install
make install%{flavor_suffix} \
  DESTDIR=%{buildroot} \
  PREFIX=%{_usr} \
  SYSCONFDIR=%{_sysconfdir} \
  UDEVRULESDIR=%{_udevrulesdir} \
  UNITDIR=%{_unitdir}

# Disable persistent net generator from udev-persistent-ifnames as
# it does not work for xen interfaces. This will likely produce a warning.
%if 0%{?suse_version} >= 1315
mkdir -p %{buildroot}/%{_sysconfdir}/udev/rules.d
ln -s /dev/null %{buildroot}/%{_sysconfdir}/udev/rules.d/75-persistent-net-generator.rules
%endif

%files -n %{base_name}%{flavor_suffix}
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/default/cloud-netconfig
%{_sysconfdir}/netconfig.d/cloud-netconfig
%{_sysconfdir}/sysconfig/network/scripts/*
%if 0%{?suse_version} >= 1315
%{_sysconfdir}/udev/rules.d
%endif
%{_udevrulesdir}/*
%{_unitdir}/*
%doc README.md
%license LICENSE

%pre
%service_add_pre %{base_name}.service %{base_name}.timer

%post
%service_add_post %{base_name}.service %{base_name}.timer

%preun
%service_del_preun %{base_name}.service %{base_name}.timer

%postun
%service_del_postun %{base_name}.service %{base_name}.timer

%changelog
* Thu Nov  5 2020 Joachim Gleissner <jgleissner@suse.com>
- Update to version 1.5:
  + Add support for GCE (bsc#1159460, bsc#1178486)
  + Improve default gateway determination
* Tue Feb  4 2020 Joachim Gleissner <jgleissner@suse.com>
- Update to version 1.4:
  + copy routes from default routing table (bsc#1162705, bsc#1162707)
  + make CLOUD_NETCONFIG_MANAGE default configurable
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through the -mini flavors.
* Thu Nov 28 2019 Joachim Gleissner <jgleissner@suse.com>
- Removed obsolete Group tag from spec file
* Tue Nov 26 2019 Joachim Gleissner <jgleissner@suse.com>
- Update to version 1.3:
  + Fix IPv4 address handling on secondary NICs in Azure
* Tue Nov 26 2019 Joachim Gleissner <jgleissner@suse.com>
- Update to version 1.2:
  + support AWS IMDSv2 token
* Thu Nov 21 2019 Joachim Gleissner <jgleissner@suse.com>
- Update to version 1.1
  + fix use of GATEWAY variable (bsc#1157117, bsc#1157190)
  + remove secondary IPv4 address only when added by cloud-netconfig
    (bsc#1144282)
  + simplify routing setup for single NIC systems (partly fixes
    bsc#1135592)
* Thu May 16 2019 Joachim Gleissner <jgleissner@suse.com>
- Update to version 1.0:
  + pause and retry if API call throttling is detected in Azure
    (bsc#1135257 bsc#1135263)
* Thu Jan 31 2019 Joachim Gleissner <jgleissner@suse.com>
- Update to version 0.9:
  + run cloud-netconfig periodically (bsc#1118783 bsc#1122013)
  + do not treat eth0 special wrt routing policies (bsc#1123008)
  + reduce timeout on metadata read (bsc#1112822)
* Fri Jun  1 2018 jgleissner@suse.com
- Update to version 0.7:
  + no persistent interface names in Azure (bsc#1095485)
* Wed Jan 17 2018 jgleissner@suse.com
- Added dependency on curl
- Use otherproviders() only on SLES 11 builds
* Fri Jan 12 2018 jgleissner@suse.com
- Remove dependency on udev-persistent-ifnames (bsc#1075484)
* Thu Nov  9 2017 adrian.glaubitz@suse.com
- Add missing Provides/Conflicts statements to spec file
* Fri Oct 13 2017 jgleissner@suse.com
- Prepare for SLE11 submission (bsc#1063292)
* Fri Oct 13 2017 jgleissner@suse.com
- Update to version 0.6:
  + Use tested and supported metadata API versions
* Wed Oct 11 2017 rjschwei@suse.com
- Update to version 0.5
  + New API version for Azure metadata server
  + Wait for the metadata server in EC2
* Tue Oct 10 2017 jgleissner@suse.com
- Update to version 0.4:
  Do not touch VF interfaces in Azure (bsc#1055553)
- Prepare for SLE submission (FATE#323820, bsc#1027212)
* Thu Sep  7 2017 jgleissner@suse.com
- Added conflict tags
- Fix requires for non-Leap platforms
* Mon Aug 14 2017 jgleissner@suse.com
- Initial version 0.3
